EXPORTS
	__14CObexMtmHeaderG4TUidl @ 1 NONAME R3UNUSED ; CObexMtmHeader::CObexMtmHeader(TUid, long)
	BaseExternalizeL__C14CObexMtmHeaderR15RMsvWriteStream @ 2 NONAME R3UNUSED ; CObexMtmHeader::BaseExternalizeL(RMsvWriteStream &) const
	BaseInternalizeL__14CObexMtmHeaderR14RMsvReadStream @ 3 NONAME R3UNUSED ; CObexMtmHeader::BaseInternalizeL(RMsvReadStream &)
	CommitStoreL__28CObexMtmFileNameExternaliser @ 4 NONAME R3UNUSED ; CObexMtmFileNameExternaliser::CommitStoreL(void)
	ConnectionID__C14CObexMtmHeader @ 5 NONAME R3UNUSED ; CObexMtmHeader::ConnectionID(void) const
	DummyCopyOfDataLC__10CContainer @ 6 NONAME R3UNUSED ; CContainer::DummyCopyOfDataLC(void)
	DummyCopyOfDataLC__10CContaineri @ 7 NONAME R3UNUSED ; CContainer::DummyCopyOfDataLC(int)
	DummyCopyOfDataLC__18CObexFileContainer @ 8 NONAME R3UNUSED ; CObexFileContainer::DummyCopyOfDataLC(void)
	DummyCopyOfDataLC__18CObexFileContaineri @ 9 NONAME R3UNUSED ; CObexFileContainer::DummyCopyOfDataLC(int)
	DummyCopyToFileContainerLC__10CContainerR3RFsRC7TDesC16 @ 10 NONAME R3UNUSED ; CContainer::DummyCopyToFileContainerLC(RFs &, TDesC16 const &)
	ExternaliseAndCommit1FileNameL__28CObexMtmFileNameExternaliserP9CMsvEntryPC7TDesC16 @ 11 NONAME R3UNUSED ; CObexMtmFileNameExternaliser::ExternaliseAndCommit1FileNameL(CMsvEntry *, TDesC16 const *)
	ExternaliseFileNameL__28CObexMtmFileNameExternaliserPC7TDesC16 @ 12 NONAME R3UNUSED ; CObexMtmFileNameExternaliser::ExternaliseFileNameL(TDesC16 const *)
	ExternalizeL__17ObexInternalUtilsPC6HBufC8R12RWriteStream @ 13 NONAME R3UNUSED ; ObexInternalUtils::ExternalizeL(HBufC8 const *, RWriteStream &)
	ExternalizeL__17ObexInternalUtilsPC7HBufC16R12RWriteStream @ 14 NONAME R3UNUSED ; ObexInternalUtils::ExternalizeL(HBufC16 const *, RWriteStream &)
	ExternalizeL__17ObexInternalUtilsRC5TDes8R12RWriteStream @ 15 NONAME R3UNUSED ; ObexInternalUtils::ExternalizeL(TDes8 const &, RWriteStream &)
	ExternalizeL__17ObexInternalUtilsRC6TDes16R12RWriteStream @ 16 NONAME R3UNUSED ; ObexInternalUtils::ExternalizeL(TDes16 const &, RWriteStream &)
	DummyFinaliseObexMessageL__10CObexUtilsR11CMsvSessionl @ 17 NONAME R3UNUSED ; CObexUtils::DummyFinaliseObexMessageL(CMsvSession &, long)
	DummyGetHeaderDetailsL__C14CBaseContainerR15CObexBaseObject @ 18 NONAME R3UNUSED ; CBaseContainer::DummyGetHeaderDetailsL(CObexBaseObject &) const
	GetPasswordLC__24ObexPasswordExternaliserR11CMsvSessionRC4TUid @ 19 NONAME R3UNUSED ; ObexPasswordExternaliser::GetPasswordLC(CMsvSession &, TUid const &)
	GetPasswordLC__24ObexPasswordExternaliserR9CMsvEntry @ 20 NONAME R3UNUSED ; ObexPasswordExternaliser::GetPasswordLC(CMsvEntry &)
	Internalise1FileNameL__28CObexMtmFileNameExternaliserP9CMsvEntryP6TDes16 @ 21 NONAME R3UNUSED ; CObexMtmFileNameExternaliser::Internalise1FileNameL(CMsvEntry *, TDes16 *)
	InternaliseFileNamesLC__28CObexMtmFileNameExternaliserR9CMsvStore @ 22 NONAME R3UNUSED ; CObexMtmFileNameExternaliser::InternaliseFileNamesLC(CMsvStore &)
	InternalizeL__17ObexInternalUtilsR5TDes8R11RReadStream @ 23 NONAME R3UNUSED ; ObexInternalUtils::InternalizeL(TDes8 &, RReadStream &)
	InternalizeL__17ObexInternalUtilsR6TDes16R11RReadStream @ 24 NONAME R3UNUSED ; ObexInternalUtils::InternalizeL(TDes16 &, RReadStream &)
	InternalizeL__17ObexInternalUtilsRP6HBufC8R11RReadStream @ 25 NONAME R3UNUSED ; ObexInternalUtils::InternalizeL(HBufC8 *&, RReadStream &)
	InternalizeL__17ObexInternalUtilsRP7HBufC16R11RReadStream @ 26 NONAME R3UNUSED ; ObexInternalUtils::InternalizeL(HBufC16 *&, RReadStream &)
	Length__C14CObexMtmHeader @ 27 NONAME R3UNUSED ; CObexMtmHeader::Length(void) const
	DummyMoveToFile__10CContainerR3RFsRC7TDesC16 @ 28 NONAME R3UNUSED ; CContainer::DummyMoveToFile(RFs &, TDesC16 const &)
	DummyMoveToFile__18CObexFileContainerR3RFsRC7TDesC16 @ 29 NONAME R3UNUSED ; CObexFileContainer::DummyMoveToFile(RFs &, TDesC16 const &)
	Name__C14CObexMtmHeader @ 30 NONAME R3UNUSED ; CObexMtmHeader::Name(void) const
	NewLC__13CObexSdpUtilsR21MObexSdpUtilsObserver @ 31 NONAME R3UNUSED ; CObexSdpUtils::NewLC(MObexSdpUtilsObserver &)
	DummyNewL__10CContainer @ 32 NONAME R3UNUSED ; CContainer::DummyNewL(void)
	DummyNewL__10CContainerP8CBufBase @ 33 NONAME R3UNUSED ; CContainer::DummyNewL(CBufBase *)
	NewL__13CObexSdpUtilsR21MObexSdpUtilsObserver @ 34 NONAME R3UNUSED ; CObexSdpUtils::NewL(MObexSdpUtilsObserver &)
	DummyNewL__18CObexFileContainerRC7TDesC16 @ 35 NONAME R3UNUSED ; CObexFileContainer::DummyNewL(TDesC16 const &)
	NewL__28CObexMtmFileNameExternaliserP11CMsvSessionl @ 36 NONAME R3UNUSED ; CObexMtmFileNameExternaliser::NewL(CMsvSession *, long)
	DummyObexBaseObject__C10CContainer @ 37 NONAME R3UNUSED ; CContainer::DummyObexBaseObject(void) const
	DummyObexBaseObject__C18CObexFileContainer @ 38 NONAME R3UNUSED ; CObexFileContainer::DummyObexBaseObject(void) const
	Panic__17ObexInternalUtilsQ217ObexInternalUtils23TObexInternalUtilsPanic @ 39 NONAME R3UNUSED ; ObexInternalUtils::Panic(ObexInternalUtils::TObexInternalUtilsPanic)
	RemoteBtObexQueryL__13CObexSdpUtilsG10TBTDevAddr @ 40 NONAME ; CObexSdpUtils::RemoteBtObexQueryL(TBTDevAddr)
	DummyRemoveFromInboxL__10CObexUtilsR11CMsvSessionl @ 41 NONAME R3UNUSED ; CObexUtils::DummyRemoveFromInboxL(CMsvSession &, long)
	ResetPasswordL__24ObexPasswordExternaliserR11CMsvSessionRC4TUid @ 42 NONAME R3UNUSED ; ObexPasswordExternaliser::ResetPasswordL(CMsvSession &, TUid const &)
	ResetPasswordL__24ObexPasswordExternaliserR9CMsvEntry @ 43 NONAME R3UNUSED ; ObexPasswordExternaliser::ResetPasswordL(CMsvEntry &)
	RestoreL__14CObexMtmHeaderRC9CMsvStore @ 44 NONAME R3UNUSED ; CObexMtmHeader::RestoreL(CMsvStore const &)
	DummySaveObjToInboxL__10CObexUtilsR11CMsvSessionR14CBaseContainerG4TUidRlR7TDesC16 @ 45 NONAME ; CObexUtils::DummySaveObjToInboxL(CMsvSession &, CBaseContainer &, TUid, long &, TDesC16 &)
	SetConnectionIDL__14CObexMtmHeaderRC6TDesC8 @ 46 NONAME R3UNUSED ; CObexMtmHeader::SetConnectionIDL(TDesC8 const &)
	DummySetHeaderDetailsL__14CBaseContainerR15CObexBaseObject @ 47 NONAME R3UNUSED ; CBaseContainer::DummySetHeaderDetailsL(CObexBaseObject &)
	SetLength__14CObexMtmHeaderi @ 48 NONAME R3UNUSED ; CObexMtmHeader::SetLength(int)
	SetNameL__14CObexMtmHeaderRC7TDesC16 @ 49 NONAME R3UNUSED ; CObexMtmHeader::SetNameL(TDesC16 const &)
	SetPasswordL__24ObexPasswordExternaliserR11CMsvSessionRC4TUidRC7TDesC16 @ 50 NONAME R3UNUSED ; ObexPasswordExternaliser::SetPasswordL(CMsvSession &, TUid const &, TDesC16 const &)
	SetPasswordL__24ObexPasswordExternaliserR9CMsvEntryRC7TDesC16 @ 51 NONAME R3UNUSED ; ObexPasswordExternaliser::SetPasswordL(CMsvEntry &, TDesC16 const &)
	SetSubjectL__14CObexMtmHeaderRC7TDesC16 @ 52 NONAME R3UNUSED ; CObexMtmHeader::SetSubjectL(TDesC16 const &)
	SetTargetL__14CObexMtmHeaderRC6TDesC8 @ 53 NONAME R3UNUSED ; CObexMtmHeader::SetTargetL(TDesC8 const &)
	SetTime__14CObexMtmHeaderRC5TTime @ 54 NONAME R3UNUSED ; CObexMtmHeader::SetTime(TTime const &)
	SetTypeL__14CObexMtmHeaderRC6TDesC8 @ 55 NONAME R3UNUSED ; CObexMtmHeader::SetTypeL(TDesC8 const &)
	StoreL__C14CObexMtmHeaderR9CMsvStore @ 56 NONAME R3UNUSED ; CObexMtmHeader::StoreL(CMsvStore &) const
	Subject__C14CObexMtmHeader @ 57 NONAME R3UNUSED ; CObexMtmHeader::Subject(void) const
	Target__C14CObexMtmHeader @ 58 NONAME R3UNUSED ; CObexMtmHeader::Target(void) const
	Time__C14CObexMtmHeader @ 59 NONAME R3UNUSED ; CObexMtmHeader::Time(void) const
	Type__C14CObexMtmHeader @ 60 NONAME R3UNUSED ; CObexMtmHeader::Type(void) const
	DummyDtorCContainer__10CContainer @ 61 NONAME R3UNUSED ; CContainer::DummyDtorCContainer(void)
	"_._14CObexMtmHeader" @ 62 NONAME R3UNUSED ; CObexMtmHeader::~CObexMtmHeader(void)
	DummyDtorCObexFileContainer__18CObexFileContainer @ 63 NONAME R3UNUSED ; CObexFileContainer::DummyDtorCObexFileContainer(void)
	BaseConstructL__14CObexMtmHeader @ 64 NONAME R3UNUSED ; CObexMtmHeader::BaseConstructL(void)
	AddHeadersToBaseObjectL__15CObexHeaderListR15CObexBaseObject @ 65 NONAME R3UNUSED ; CObexHeaderList::AddHeadersToBaseObjectL(CObexBaseObject &)
	Count__C15CObexHeaderList @ 66 NONAME R3UNUSED ; CObexHeaderList::Count(void) const
	ExternalizeL__C15CObexHeaderListR15RMsvWriteStream @ 67 NONAME R3UNUSED ; CObexHeaderList::ExternalizeL(RMsvWriteStream &) const
	InternalizeL__15CObexHeaderListR14RMsvReadStream @ 68 NONAME R3UNUSED ; CObexHeaderList::InternalizeL(RMsvReadStream &)
	NewLC__15CObexHeaderList @ 69 NONAME R3UNUSED ; CObexHeaderList::NewLC(void)
	NewL__15CObexHeaderList @ 70 NONAME R3UNUSED ; CObexHeaderList::NewL(void)
	ObexHeaderL__15CObexHeaderListi @ 71 NONAME R3UNUSED ; CObexHeaderList::ObexHeaderL(int)
	"_._15CObexHeaderList" @ 72 NONAME R3UNUSED ; CObexHeaderList::~CObexHeaderList(void)
	AddHeader__15CObexHeaderListPC11CObexHeader @ 73 NONAME R3UNUSED ; CObexHeaderList::AddHeader(CObexHeader const *)
	ExternaliseFileNameAndHeadersL__28CObexMtmFileNameExternaliserPC7TDesC16PC15CObexHeaderList @ 74 NONAME R3UNUSED ; CObexMtmFileNameExternaliser::ExternaliseFileNameAndHeadersL(TDesC16 const *, CObexHeaderList const *)
	NewL__27CObexMtmFileNameWithHeaders @ 75 NONAME R3UNUSED ; CObexMtmFileNameWithHeaders::NewL(void)

